@@ -51,8 +51,6 @@ package com.openexchange.mobile.configuration.json.action.sms.osgi;
 
 import static com.openexchange.mobile.configuration.json.action.sms.osgi.ActionServiceRegistry.getServiceRegistry;
 import java.util.Hashtable;
-import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.mobile.configuration.json.action.ActionService;
 import com.openexchange.mobile.configuration.json.action.ActionTypes;
@@ -65,7 +63,7 @@ import com.openexchange.osgi.ServiceRegistry;
  */
 public class ActionActivator extends HousekeepingActivator {
 
-	private static transient final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(ActionActivator.class));
+	private static transient final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(ActionActivator.class);
 
 	private static final Class<?>[] NEEDED_SERVICES = { ConfigurationService.class } ;
 
@@ -80,17 +78,13 @@ public class ActionActivator extends HousekeepingActivator {
 
 	@Override
 	protected void handleAvailability(final Class<?> clazz) {
-		if (LOG.isWarnEnabled()) {
-			LOG.warn("Absent service: " + clazz.getName());
-		}
+		LOG.warn("Absent service: {}", clazz.getName());
 		getServiceRegistry().addService(clazz, getService(clazz));
 	}
 
 	@Override
 	protected void handleUnavailability(final Class<?> clazz) {
-		if (LOG.isInfoEnabled()) {
-			LOG.info("Re-available service: " + clazz.getName());
-		}
+		LOG.info("Re-available service: {}", clazz.getName());
 		getServiceRegistry().removeService(clazz);
 	}
 
@@ -116,7 +110,7 @@ public class ActionActivator extends HousekeepingActivator {
 	        ht.put("action", ActionTypes.TELEPHONE);
 	        registerService(ActionService.class, new ActionSMS(), ht);
 		} catch (final Throwable t) {
-			LOG.error(t.getMessage(), t);
+			LOG.error("", t);
 			throw t instanceof Exception ? (Exception) t : new Exception(t);
 		}
 
@@ -131,7 +125,7 @@ public class ActionActivator extends HousekeepingActivator {
              */
 			getServiceRegistry().clearRegistry();
 		} catch (final Throwable t) {
-			LOG.error(t.getMessage(), t);
+			LOG.error("", t);
 			throw t instanceof Exception ? (Exception) t : new Exception(t);
 		}
 	}
